@@ -15,13 +15,13 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gnome2-VFS/vfs2perl.h,v 1.15 2003/12/19 17:26:24 kaffeetisch Exp $
+ * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gnome2-VFS/vfs2perl.h,v 1.15.2.1 2004/06/25 14:49:03 kaffeetisch Exp $
  */
 
 #ifndef _VFS2PERL_H_
 #define _VFS2PERL_H_
 
-#include <gtk2perl.h>
+#include <gperl.h>
 
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
